==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QUntypedPropertyBinding_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qproperty.h>
#include <QtCore/QVariant>
#include <QtCore/qmetatype.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QUntypedPropertyBinding(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QUntypedPropertyBinding")
    QUntypedPropertyBinding *_ptr = reinterpret_cast<QUntypedPropertyBinding *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QUntypedPropertyBinding()
void __qt_construct_QUntypedPropertyBinding_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QUntypedPropertyBinding()")
    Q_UNUSED(__java_arguments)
    QUntypedPropertyBinding *__qt_this = new(__qtjambi_ptr) QUntypedPropertyBinding();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QUntypedPropertyBinding(QUntypedPropertyBinding)
void __qt_construct_QUntypedPropertyBinding_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QUntypedPropertyBinding(QUntypedPropertyBinding)")
    jobject other0 = __java_arguments[0].l;
    const QUntypedPropertyBinding& __qt_other0 = qtjambi_cast<const QUntypedPropertyBinding& >(__jni_env, other0);
    QUntypedPropertyBinding *__qt_this = new(__qtjambi_ptr) QUntypedPropertyBinding(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QUntypedPropertyBinding
void __qt_destruct_QUntypedPropertyBinding(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QUntypedPropertyBinding")
    reinterpret_cast<QUntypedPropertyBinding*>(ptr)->~QUntypedPropertyBinding();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QUntypedPropertyBinding::QUntypedPropertyBinding()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_initialize_1native__Lio_qt_core_QUntypedPropertyBinding_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QUntypedPropertyBinding::QUntypedPropertyBinding()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QUntypedPropertyBinding_0, sizeof(QUntypedPropertyBinding), typeid(QUntypedPropertyBinding), false, &deleter_QUntypedPropertyBinding, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QUntypedPropertyBinding::error()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_error_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QUntypedPropertyBinding *__qt_this = QtJambiAPI::objectFromNativeId<QUntypedPropertyBinding>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QUntypedPropertyBinding::error()const", __qt_this)
        QPropertyBindingError __qt_return_value = __qt_this->error();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QUntypedPropertyBinding::isNull()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_isNull_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QUntypedPropertyBinding *__qt_this = QtJambiAPI::objectFromNativeId<QUntypedPropertyBinding>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QUntypedPropertyBinding::isNull()const", __qt_this)
        __java_return_value = __qt_this->isNull();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QUntypedPropertyBinding::operator=(QUntypedPropertyBinding)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_assign_1native_1cref_1QUntypedPropertyBinding__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QUntypedPropertyBinding *__qt_this = QtJambiAPI::objectFromNativeId<QUntypedPropertyBinding>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QUntypedPropertyBinding::operator=(QUntypedPropertyBinding)", __qt_this)
        const QUntypedPropertyBinding& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QUntypedPropertyBinding>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QUntypedPropertyBinding::valueMetaType()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_valueMetaType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QUntypedPropertyBinding *__qt_this = QtJambiAPI::objectFromNativeId<QUntypedPropertyBinding>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QUntypedPropertyBinding::valueMetaType()const", __qt_this)
        QMetaType __qt_return_value = __qt_this->valueMetaType();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QUntypedPropertyBinding(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QUntypedPropertyBinding>("QUntypedPropertyBinding", "io/qt/core/QUntypedPropertyBinding");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QUntypedPropertyBinding, {
        ConstructorInfo(&__qt_construct_QUntypedPropertyBinding_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QUntypedPropertyBinding_1, "Lio/qt/core/QUntypedPropertyBinding;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QUntypedPropertyBinding);
    registerMetaType<QUntypedPropertyBinding>("QUntypedPropertyBinding");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QUntypedPropertyBinding_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qproperty.h>
#include <QtCore/QVariant>
#include <QtCore/qmetatype.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QUntypedPropertyBinding(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QUntypedPropertyBinding")
    QUntypedPropertyBinding *_ptr = reinterpret_cast<QUntypedPropertyBinding *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QUntypedPropertyBinding()
void __qt_construct_QUntypedPropertyBinding(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QUntypedPropertyBinding()")
    Q_UNUSED(__java_arguments)
    QUntypedPropertyBinding *__qt_this = new(__qtjambi_ptr) QUntypedPropertyBinding();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QUntypedPropertyBinding::QUntypedPropertyBinding()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_initialize_1native__Lio_qt_core_QUntypedPropertyBinding_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QUntypedPropertyBinding::QUntypedPropertyBinding()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QUntypedPropertyBinding, sizeof(QUntypedPropertyBinding), typeid(QUntypedPropertyBinding), false, &deleter_QUntypedPropertyBinding, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QUntypedPropertyBinding(QUntypedPropertyBinding)
void __qt_construct_QUntypedPropertyBinding_cref_QUntypedPropertyBinding(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QUntypedPropertyBinding(QUntypedPropertyBinding)")
    jobject other0 = __java_arguments[0].l;
    const QUntypedPropertyBinding& __qt_other0 = qtjambi_cast<const QUntypedPropertyBinding& >(__jni_env, other0);
    QUntypedPropertyBinding *__qt_this = new(__qtjambi_ptr) QUntypedPropertyBinding(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QUntypedPropertyBinding
void __qt_destruct_QUntypedPropertyBinding(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QUntypedPropertyBinding")
    reinterpret_cast<QUntypedPropertyBinding*>(ptr)->~QUntypedPropertyBinding();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QUntypedPropertyBinding::error()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_error_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QUntypedPropertyBinding *__qt_this = QtJambiAPI::objectFromNativeId<QUntypedPropertyBinding>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QUntypedPropertyBinding::error()const", __qt_this)
        QPropertyBindingError __qt_return_value = __qt_this->error();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QUntypedPropertyBinding::isNull()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_isNull_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QUntypedPropertyBinding *__qt_this = QtJambiAPI::objectFromNativeId<QUntypedPropertyBinding>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QUntypedPropertyBinding::isNull()const", __qt_this)
        __java_return_value = __qt_this->isNull();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QUntypedPropertyBinding::operator=(QUntypedPropertyBinding)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_assign_1native_1cref_1QUntypedPropertyBinding__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QUntypedPropertyBinding *__qt_this = QtJambiAPI::objectFromNativeId<QUntypedPropertyBinding>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QUntypedPropertyBinding::operator=(QUntypedPropertyBinding)", __qt_this)
        const QUntypedPropertyBinding& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QUntypedPropertyBinding>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QUntypedPropertyBinding::valueMetaType()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QUntypedPropertyBinding_valueMetaType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QUntypedPropertyBinding *__qt_this = QtJambiAPI::objectFromNativeId<QUntypedPropertyBinding>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QUntypedPropertyBinding::valueMetaType()const", __qt_this)
        QMetaType __qt_return_value = __qt_this->valueMetaType();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QUntypedPropertyBinding(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QUntypedPropertyBinding>("QUntypedPropertyBinding", "io/qt/core/QUntypedPropertyBinding");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QUntypedPropertyBinding, {
        ConstructorInfo(&__qt_construct_QUntypedPropertyBinding, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QUntypedPropertyBinding);
    registerMetaType<QUntypedPropertyBinding>("QUntypedPropertyBinding");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
